API Reference
============

This section provides detailed API documentation for all DataLib modules.

.. toctree::
   :maxdepth: 2

   data_manipulation
   statistics
   visualization
   ml

Data Manipulation
---------------

.. automodule:: datalib.data_manipulation
   :members:
   :undoc-members:
   :show-inheritance:

Statistics
---------

.. automodule:: datalib.statistics
   :members:
   :undoc-members:
   :show-inheritance:

Visualization
------------

.. automodule:: datalib.visualization
   :members:
   :undoc-members:
   :show-inheritance:

Machine Learning
--------------

.. automodule:: datalib.ml
   :members:
   :undoc-members:
   :show-inheritance: 